==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/content-viewer/state/external-viewer/external-viewer.effects.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import * as ExternalViewerActions from './external-viewer.actions';
import { tap } from 'rxjs';
import { NavigationExtras, Router } from '@angular/router';

@Injectable()
export class ExternalViewerEffects {
    constructor(
        private actions$: Actions,
        private router: Router
    ) {}

    navigateToExternalViewer$ = createEffect(
        () =>
            this.actions$.pipe(
                ofType(ExternalViewerActions.navigateToExternalViewer),
                tap(() => {
                    const extras: NavigationExtras = {
                        queryParamsHandling: 'preserve',
                        replaceUrl: true
                    };
                    this.router.navigate(['/content-viewer', 'external'], extras);
                })
            ),
        { dispatch: false }
    );
}

==> nifi-2.8.0-source-release.zip: nifi-2.8.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/content-viewer/state/external-viewer/external-viewer.effects.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable, inject } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import * as ExternalViewerActions from './external-viewer.actions';
import { tap } from 'rxjs';
import { NavigationExtras, Router } from '@angular/router';

@Injectable()
export class ExternalViewerEffects {
    private actions$ = inject(Actions);
    private router = inject(Router);

    navigateToExternalViewer$ = createEffect(
        () =>
            this.actions$.pipe(
                ofType(ExternalViewerActions.navigateToExternalViewer),
                tap(() => {
                    const extras: NavigationExtras = {
                        queryParamsHandling: 'preserve',
                        replaceUrl: true
                    };
                    this.router.navigate(['/content-viewer', 'external'], extras);
                })
            ),
        { dispatch: false }
    );
}
